/* Written by Morgoth DBMA, morgothdbma@o2.pl
 This is part of PgXexplorer software, Open Source
 on BSD licence, Libraries(interaces) used:
 GNU GCC, AS (all stuff needed to compile C source into executable binary)
 LibPQ-FE from PostgreSQL, GTK (GIMP Toolkit)
 written in VIM editor, ctags used, CVS used
 Currently only one author: MOrgoth DBMA
 FILE: gtkdialogs.h */
#ifndef __MORGOTHDBMA_GTKTEST__
#define __MORGOTHDBMA_GTKTEST__
#include "gtkincl.h"
#include "query.h"
#include "consoleout.h"
#define ANSWER_YES 1
#define ANSWER_NO  0
#define MAX_ENTRY_LENGTH 1024
#define MAX_MSG_LENGTH   4608
#define MASK_LENGTH        32
int gtk_dialog_yes_no(const char*);
int gtk_dialog_with_2_buttons(const char*, char*, char*);
int gtk_dialog_yes_no_printf(const char*, ...);
char* gtk_dialog_gettext(const char*);
char* gtk_dialog_gettext_printf(const char*, ...);
char* gtk_dialog_getfile_printf(const char*, const char*, ...);
char* gtk_dialog_getfile(const char*, const char*);
void gtk_dialog_mbox(const char*, const char*);
void gtk_dialog_printf_with_title(const char*, const char*, ...);
void gtk_dialog_printf_big_with_title(const char*, const char*, ...);
void gtk_dialog_printf(const char*, ...);
void gtk_dialog_printf_big(const char*, ...);
char* gtk_dialog_getdbs(PGconn*, char*,...);
#endif
